==> open_watcom_1.4.0-src.zip: bld/f77/f77lib/c/ioinit.c <==
/****************************************************************************
*
*                            Open Watcom Project
*
*    Portions Copyright (c) 1983-2002 Sybase, Inc. All Rights Reserved.
*
*  ========================================================================
*
*    This file contains Original Code and/or Modifications of Original
*    Code as defined in and that are subject to the Sybase Open Watcom
*    Public License version 1.0 (the 'License'). You may not use this file
*    except in compliance with the License. BY USING THIS FILE YOU AGREE TO
*    ALL TERMS AND CONDITIONS OF THE LICENSE. A copy of the License is
*    provided with the Original Code and Modifications, and is also
*    available at www.sybase.com/developer/opensource.
*
*    The Original Code and all software distributed under the License are
*    distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
*    EXPRESS OR IMPLIED, AND SYBASE AND ALL CONTRIBUTORS HEREBY DISCLAIM
*    ALL SUCH WARRANTIES, INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF
*    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR
*    NON-INFRINGEMENT. Please see the License for the specific language
*    governing rights and limitations under the License.
*
*  ========================================================================
*
* Description:  WHEN YOU FIGURE OUT WHAT THIS FILE DOES, PLEASE
*               DESCRIBE IT HERE!
*
****************************************************************************/


//
// IOINIT       : I/O system initialization
//

#include "ftnstd.h"
#include "ftnio.h"

#include <stdlib.h>

extern  bool            RunEntry(void);
extern  void            RunExit(void);
extern  void            Suicide(void);

static  char            IOSysInitialized = { 0 };


static  void            IOSysFini() {
//===================================

// Finalize I/O system.

    RunExit();
}


void            IOSysInit() {
//===========================

// Initialize I/O system.

    if( IOSysInitialized ) return;
    IOSysInitialized = 1;
    atexit( &IOSysFini );
    if( RunEntry() ) return;
    Suicide();
}

==> open_watcom_1.7.1-src.zip: bld/f77/f77lib/c/ioinit.c <==
/****************************************************************************
*
*                            Open Watcom Project
*
*    Portions Copyright (c) 1983-2002 Sybase, Inc. All Rights Reserved.
*
*  ========================================================================
*
*    This file contains Original Code and/or Modifications of Original
*    Code as defined in and that are subject to the Sybase Open Watcom
*    Public License version 1.0 (the 'License'). You may not use this file
*    except in compliance with the License. BY USING THIS FILE YOU AGREE TO
*    ALL TERMS AND CONDITIONS OF THE LICENSE. A copy of the License is
*    provided with the Original Code and Modifications, and is also
*    available at www.sybase.com/developer/opensource.
*
*    The Original Code and all software distributed under the License are
*    distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
*    EXPRESS OR IMPLIED, AND SYBASE AND ALL CONTRIBUTORS HEREBY DISCLAIM
*    ALL SUCH WARRANTIES, INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF
*    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR
*    NON-INFRINGEMENT. Please see the License for the specific language
*    governing rights and limitations under the License.
*
*  ========================================================================
*
* Description:  WHEN YOU FIGURE OUT WHAT THIS FILE DOES, PLEASE
*               DESCRIBE IT HERE!
*
****************************************************************************/


//
// IOINIT       : I/O system initialization
//

#include "ftnstd.h"
#include "ftnio.h"

#include <stdlib.h>

extern  bool            RunEntry(void);
extern  void            RunExit(void);
extern  void            Suicide(void);

static  char            IOSysInitialized = { 0 };


static  void            IOSysFini( void ) {
//===================================

// Finalize I/O system.

    RunExit();
}


void            IOSysInit( void ) {
//===========================

// Initialize I/O system.

    if( IOSysInitialized ) return;
    IOSysInitialized = 1;
    atexit( &IOSysFini );
    if( RunEntry() ) return;
    Suicide();
}
